Disney Channel Original Movies | Zenon, Smart House, Luck of the Irish | TeenVogue.com
Author: Teen Vogue Magazine
Description: Check out these seven Disney Channel Original Movies your life won't be complete without seeing.

Close
Close
Close

##### Entertainment

# 7 Disney Channel Original Movies That You Need to See Immediately

- More

As you may remember from High School Musical or Camp Rock or The Cheetah Girls, Disney Channel Original Movies aren't just made-for-TV movies, but actual events. Like something you looked forward to forever because it was basically like being at the exciting opening night showing, only in your own home.

Not that the recent DCOM selection isn't great and all, but we definitely suggest locating these movies over holiday break and watching them over and over again. Scrunchies and roll-on body glitter optional.

- E-Mail

## We're all supernova girls!

#####

##

As you may remember from High School Musical or Camp Rock or The Cheetah Girls, Disney Channel Original Movies aren't just made-for-TV movies, but actual events. Like something you looked forward to forever because it was basically like being at the exciting opening night showing, only in your own home.

Not that the recent DCOM selection isn't great and all, but we definitely suggest locating these movies over holiday break and watching them over and over again. Scrunchies and roll-on body glitter optional.

show comments

## What do you think?

#### Post a comment

## We're all supernova girls!

by Hannah Gilman

#####

##

###